@@ -16,6 +16,17 @@ for epoch in reloading(range(10)):
     print('INITIAL_FILE_CONTENTS')
 """
 
+TEST_CHANGING_LINE_NUMBER_OF_LOOP = """
+from reloading import reloading
+from time import sleep
+
+pass
+
+for epoch in reloading(range(10)):
+    sleep(0.2)
+    print('INITIAL_FILE_CONTENTS')
+"""
+
 TEST_CHANGING_SOURCE_FN_CONTENT = """
 from reloading import reloading
 from time import sleep
@@ -130,6 +141,21 @@ class TestReloading(unittest.TestCase):
 
             self.assertTrue("INITIAL_FILE_CONTENTS" in stdout and "CHANGED_FILE_CONTENTS" in stdout)
 
+    def test_changing_line_number_of_loop(self):
+        for bin in ["python", "python3"]:
+            stdout, _ = run_and_update_source(
+                init_src=TEST_CHANGING_LINE_NUMBER_OF_LOOP,
+                updated_src=(
+                    TEST_CHANGING_LINE_NUMBER_OF_LOOP
+                        .replace("pass", "pass\npass\n")
+                        .replace("INITIAL", "CHANGED")
+                        .rstrip("\n")
+                ),
+                bin=bin,
+            )
+
+            self.assertTrue("INITIAL_FILE_CONTENTS" in stdout and "CHANGED_FILE_CONTENTS" in stdout)
+
     def test_comment_after_loop(self):
         for bin in ["python", "python3"]:
             stdout, _ = run_and_update_source(
